%bcond_without tests

%global debug_package %{nil}
%global python3_pkgversion 39
%global __python3 %{_bindir}/python3.9
%global __pytest /usr/bin/pytest-3.9

Name:		wult
Version:	1.10.27
Release:	1%{?dist}
Summary:	A tool for measuring C-state latency in Linux

License:	BSD-3-Clause
Url:		https://intel.github.io/wult
Source0:	https://github.com/intel/wult/archive/v%{version}/%{name}-%{version}.tar.gz

Patch0:		libbpf-static.patch

ExclusiveArch:	x86_64

BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	libbpf-devel
BuildRequires:	libbpf-static
BuildRequires:	python%{python3_pkgversion}-devel
BuildRequires:	python%{python3_pkgversion}-plotly
BuildRequires:	pepc >= 1.3.16
%if %{with tests}
BuildRequires:	python%{python3_pkgversion}-pandas
BuildRequires:	python%{python3_pkgversion}-pluggy
BuildRequires:	python%{python3_pkgversion}-pytest
BuildRequires:	python%{python3_pkgversion}-numpy
BuildRequires:	python%{python3_pkgversion}-yaml
%endif
Requires:	pepc >= 1.3.16
Requires:	pciutils
Requires:	python%{python3_pkgversion}-pandas
Requires:	python%{python3_pkgversion}-plotly
Requires:	python%{python3_pkgversion}-numpy
Requires:	python%{python3_pkgversion}-yaml
Requires:	python%{python3_pkgversion}-wult
Requires:	%{name}-devel = %{version}-%{release}

%description
The name Wult comes from "Wake Up Latency Tracer". Wult measures C-state
latency by scheduling a delayed interrupt at a known time in the future, so it
relies on devices allowing for delayed interrupts. Today wult can use LAPIC as
the source of delayed interrupts, as well as I210 PCIe Gigabit Ethernet
adapter. However, other devices could be supported as well, for example other
Intel Ethernet adapters.

%package -n python%{python3_pkgversion}-%{name}
Summary:	Wult Python library
Requires:	wult = %{version}-%{release}

%description -n python%{python3_pkgversion}-%{name}
Wult Python library

%package -n %{name}-devel
Summary:        Wult Kernel drivers
Requires:	dwarves
Requires:	elfutils-libelf-devel
Requires:	wult = %{version}-%{release}

%description -n %{name}-devel
Wult Kernel drivers

%prep
%autosetup -n %{name}-%{version} -p1

# only for c8s
for f in wult ndl helpers/stc-agent/ipmi-helper helpers/stc-agent/stc-agent
do
  sed -i '1 s/python3/python3.9/' $f
done 

%build
%py3_build
make -C helpers/ndlrunner
make -C helpers/wultrunner

%install
%py3_install
install -pDm755 helpers/ndlrunner/ndlrunner %{buildroot}%{_bindir}/ndlrunner
install -pDm755 helpers/wultrunner/wultrunner %{buildroot}%{_bindir}/wultrunner

%check
%if %{with tests}
%pytest -v
%endif

%files
%doc README.md CHANGELOG.md
%license LICENSE.md js/dist/main.js.LICENSE.txt
%{_bindir}/ipmi-helper
%{_bindir}/ndl
%{_bindir}/ndlrunner
%{_bindir}/stc-agent
%{_bindir}/wult
%{_bindir}/wultrunner
%{_datadir}/wult/defs
%{_datadir}/wult/js
%{_datadir}/wult/misc
%exclude %{_datadir}/wult/helpers

%files -n python%{python3_pkgversion}-%{name}
%{python3_sitelib}/wultlibs
%{python3_sitelib}/wulttools
%{python3_sitelib}/statscollectlibs
%{python3_sitelib}/wult-*.egg-info/

%files -n %{name}-devel
%{_datadir}/wult/drivers

%changelog
* Wed Sep 07 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.27-1
- Update to 1.10.27

* Tue Sep 06 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.26-1
- Update to 1.10.26

* Wed Aug 31 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.25-1
- Update to 1.10.25

* Mon Aug 29 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.23-2
- Wultrunner binary fix

* Mon Aug 29 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.23-1
- Update to 1.10.23

* Thu Aug 25 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.22-1
- Update to 1.10.22

* Mon Aug 01 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.12-1
- Update to 1.10.12

* Thu Jul 21 2022 Ali Erdinc Koroglku <aekoroglu@centosproject.org> - 1.10.11-1
- Update to 1.10.11

* Thu Jul 07 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.9-1
- Update to 1.10.9

* Mon Jul 04 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.8-1
- Update to 1.10.8

* Tue Jun 28 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.7-1
- Update to 1.10.7

* Sat Jun 25 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.6-1
- Update to 1.10.6

* Tue Jun 21 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-3
- Pyyaml typo fix and dwarves dependency

* Mon Jun 20 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-2
- Deploy.py helpers typo fix

* Sun Jun 19 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-1
- Initial package
